@@ -1,6 +1,5 @@
 if (getRversion() >= '2.15.1') globalVariables(c(
-    "tl", ".HTML.file",
-    "last.table", "top", "dtm", "corpus", "corpusList", "corpusCa", "buttonsFrame",
+    "tl", "last.table", "top", "dtm", "corpus", "corpusList", "corpusCa", "buttonsFrame",
     "clustDtm", "corpusClust", "clusters", "corpusVars", "diss",
     "freqTerms", "sourceVariable", "lowercaseVariable",
     "punctuationVariable", "numbersVariable", "stopwordsVariable",
@@ -297,23 +296,29 @@ if (getRversion() >= '2.15.1') globalVariables(c(
 .validate.unum <- function(P, ..., fun=NULL) {
     # Empty string must be allowed so that the user can remove
     # all chars before typing a new value
-    if(P != "" && (suppressWarnings(is.na(as.numeric(P))) || as.numeric(P) <= 0)) {
-        tcl("expr", "false")
+    if(P == "") {
+        tcl("expr", "true")
     }
-    else {
+    else if(suppressWarnings(!is.na(as.numeric(P))) && as.numeric(P) > 0) {
         if(!is.null(fun)) fun(as.numeric(P))
         tcl("expr", "true")
     }
+    else {
+        tcl("expr", "false")
+    }
 }
 
 .validate.uint <- function(P, ..., fun=NULL) {
     # Empty string must be allowed so that the user can remove
     # all chars before typing a new value
-    if(P != "" && (suppressWarnings(is.na(as.integer(P))) || as.integer(P) <= 0)) {
-        tcl("expr", "false")
+    if(P == "") {
+        tcl("expr", "true")
     }
-    else {
+    else if(suppressWarnings(!is.na(as.integer(P))) && as.integer(P) > 0) {
         if(!is.null(fun)) fun(as.integer(P))
         tcl("expr", "true")
     }
+    else {
+        tcl("expr", "false")
+    }
 }
